@@ -3,9 +3,16 @@ package App::Netdisco::Configuration;
 use App::Netdisco::Environment;
 use Dancer ':script';
 
+use Path::Class 'dir';
+
 BEGIN {
-  # stuff useful locations into @INC
-  unshift @INC, @{ (setting('include_paths') || []) };
+  if (setting('include_paths') and ref [] eq ref setting('include_paths')) {
+    # stuff useful locations into @INC
+    push @{setting('include_paths')},
+         dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'nd-site-local', 'lib')->stringify
+      if (setting('site_local_files'));
+    unshift @INC, @{setting('include_paths')};
+  }
 }
 
 # set up database schema config from simple config vars
@@ -59,6 +66,42 @@ if (exists setting('workers')->{interactives}
 setting('dns')->{hosts_file} ||= '/etc/hosts';
 setting('dns')->{no} ||= ['fe80::/64','169.254.0.0/16'];
 
+# load /etc/hosts
+setting('dns')->{'ETCHOSTS'} = {};
+{
+  # AE::DNS::EtcHosts only works for A/AAAA/SRV, but we want PTR.
+  # this loads+parses /etc/hosts file using AE. dirty hack.
+  use AnyEvent::Socket 'format_address';
+  use AnyEvent::DNS::EtcHosts;
+  AnyEvent::DNS::EtcHosts::_load_hosts_unless(sub{},AE::cv);
+  no AnyEvent::DNS::EtcHosts; # unimport
+
+  setting('dns')->{'ETCHOSTS'}->{$_} =
+    [ map { [ $_ ? (format_address $_->[0]) : '' ] }
+          @{ $AnyEvent::DNS::EtcHosts::HOSTS{ $_ } } ]
+    for keys %AnyEvent::DNS::EtcHosts::HOSTS;
+}
+
+# support unordered dictionary as if it were a single item list
+if (ref {} eq ref setting('device_identity')) {
+  config->{'device_identity'} = [ setting('device_identity') ];
+}
+else { config->{'device_identity'} ||= [] }
+
+# copy devices_no and devices_only into others
+foreach my $name (qw/devices_no devices_only
+                    discover_no macsuck_no arpnip_no nbtstat_no
+                    discover_only macsuck_only arpnip_only nbtstat_only/) {
+  config->{$name} ||= [];
+  config->{$name} = [setting($name)] if ref [] ne ref setting($name);
+}
+foreach my $name (qw/discover_no macsuck_no arpnip_no nbtstat_no/) {
+  push @{setting($name)}, @{ setting('devices_no') };
+}
+foreach my $name (qw/discover_only macsuck_only arpnip_only nbtstat_only/) {
+  push @{setting($name)}, @{ setting('devices_only') };
+}
+
 # legacy config item names
 
 config->{'devport_vlan_limit'} =
